# PMG Toolbox

This package contains functions I've found myself using over and over in various projects. If you find them useful, please go ahead and use them. Much appreciated if you let me know. If you find better ways of accomplishing the same task (or spot a bug!), please let me know even more... I'm always eager to learn.

This is an ecclectic collection of functions. I've worked on several projects using LaTeX and SQLite, which is why there are specific helper functions for these technologies. One of the main goals of the `pmg` package is to help me ensure consistency in how I solve problems, especially when working with technologies that aren't used every day.